@@ -1,9 +1,17 @@
 # coding: utf-8
-# Standard Python libraries
-from importlib import resources
 
 # Read version from VERSION file
-__version__ = resources.read_text('atomman', 'VERSION').strip()
+try:
+    from importlib import resources
+except:
+    from pathlib import Path
+    with open(Path(Path(__file__).resolve().parent, 'VERSION')) as version_file:
+        __version__ = version_file.read().strip()
+else:
+    __version__ = resources.read_text('atomman', 'VERSION').strip()
+
+# potentials imports
+from potentials import build_lammps_potential, Settings
 
 # atomman imports
 from . import unitconvert
@@ -14,6 +22,8 @@ from .dump import *
 from .dump import __all__ as dump_all
 from .core import *
 from .core import __all__ as core_all
+from . import library
+from .library import load_lammps_potential
 from .load import *
 from .load import __all__ as load_all
 from . import plot
@@ -21,6 +31,7 @@ from . import defect
 
 
 __all__ = ['__version__'] + dump_all + core_all + load_all
+__all__ += ['load_lammps_potential', 'build_lammps_potential']
 __all__.sort()
 
 # Define default working units
